import pytest
import time

class DurationTracker:
    def __init__(self):
        self.test_durations = []

    def add_duration(self, name, duration):
        self.test_durations.append((name, duration))

    def report(self):
        print("\n--- Test Durations ---")
        for name, duration in self.test_durations:
            print(f"{name}: {duration:.4f} seconds")
        total = sum(duration for _, duration in self.test_durations)
        print(f"Total: {total:.4f} seconds")

tracker = DurationTracker()


def pytest_addoption(parser):
    """Add a custom command-line option for the plugin."""
    parser.addoption(
        "--track-duration", action="store_true", help="Track the duration of each test"
    )


def pytest_runtest_protocol(item, nextitem):
    if item.config.getoption("--track-duration"):
        print(f"Tracking duration for: {item.name}")
    

def pytest_sessionfinish(session, exitstatus):
    """Display the report after all tests have finished."""
    if session.config.getoption("--track-duration"):
        tracker.report()

def pytest_runtest_logreport(report):
    if report.when == "call" and report.failed:
        print()
        print(f"Test {report.nodeid} failed!")
    elif report.when == "call" and report.passed:
        print()
        print(f"Test {report.nodeid} passed!")

def pytest_configure(config):
    config.addinivalue_line("markers", "slow: marks tests as slow")
    config.addinivalue_line("markers", "fast: marks tests as fast")

def pytest_report_header(config):
    return "Custom Header: My custom pytest plugin is active!"





